# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information
import os
import sys
sys.path.insert(0, os.path.abspath('../'))

def skip(app, what, name, obj, would_skip, options):
    if name in ( '__init__',):
        return False
    return would_skip
def setup(app):
    app.connect('autodoc-skip-member', skip)


project = 'gros_client_py_markdown'
copyright = '2023, Matteo Ferla'
author = 'Matteo Ferla'

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.viewcode',
    'sphinx.ext.todo',
    'sphinx_markdown_builder'
]

templates_path = ['_templates']
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

language = 'en'

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_theme = 'alabaster'
html_static_path = ['_static']


todo_include_todos = True



import os
import sys

project = 'Fourier-GROS'
copyright = '2023, Fourier Software Department'
author = 'Fourier Software Department'
release = '1.0'

sys.path.insert(0, os.path.abspath('../../'))

extensions = [
    'sphinx.ext.autodoc',       # 包括来自docstrings的文档
    'sphinx.ext.napoleon',      # 启用NumPy或Google样式的文档风格
    'sphinx.ext.intersphinx',   # 链接到其他文档
    'sphinx.ext.todo',          # 支持todo项
    'sphinx.ext.coverage',      # 收集文档覆盖率统计
]

exclude_patterns = []

language = 'zh_CN'
templates_path = ['_templates']

html_static_path = ['_static']
html_theme = 'sphinx_rtd_theme'
